summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmskysphereedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmskysphereedit.h')
-rw-r--r--kpovmodeler/pmskysphereedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmskysphereedit.h b/kpovmodeler/pmskysphereedit.h
index f0e2946e..2f8c811e 100644
--- a/kpovmodeler/pmskysphereedit.h
+++ b/kpovmodeler/pmskysphereedit.h
@@ -34,12 +34,13 @@ class PMSkySphere;
class PMSkySphereEdit : public PMTextureBaseEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMSkySphereEdit with parent and name
*/
- PMSkySphereEdit( TQWidget* parent, const char* name = 0 );
+ PMSkySphereEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -34,12 +34,13 @@ class PMSkySphere;
public:
/**
- * Creates a PMSkySphereEdit with parent and name
+ * Creates a PMSkySphereEdit with tqparent and name
*/